Plato Documentation
===================

.. mdinclude:: ../../README.md

Contents:
=========

.. toctree::
   :maxdepth: 2

   primitives
   fresnel
   matplotlib
   povray
   pythreejs
   vispy
   zdog
   imperative
   troubleshooting

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
